@@ -2,17 +2,16 @@ import asyncio
 import datetime
 import logging
 import re
-from functools import wraps
 from textwrap import shorten
 from urllib.parse import urljoin
 
 from qiskit.providers import JobStatus
 from tornado.escape import json_decode, json_encode
-from tornado.httpclient import (AsyncHTTPClient, HTTPClient, HTTPError,
-                                HTTPRequest)
+from tornado.httpclient import AsyncHTTPClient, HTTPError, HTTPRequest
 from tornado.httputil import url_concat
 
 from qctic.schemas import BackendStatusSchema, GetJobsQuerySchema, JobSchema
+from qctic.utils import qasm_qobj_to_dict
 
 _SCHEME_REGEX = r"^.+://.*"
 _SCHEME_DEFAULT = "http"
@@ -32,7 +31,7 @@ class QCticAPIError(Exception):
 
 
 class QCticAPI:
-    """Class that represents the Erwin simulation API interface."""
+    """Class that represents the QUTE simulation API interface."""
 
     DEFAULT_HOST = "http://localhost"
 
@@ -242,7 +241,7 @@ class QCticAPI:
         """
 
         job_init = {
-            "qobj": job.qobj().to_dict(),
+            "qobj": qasm_qobj_to_dict(job.qobj()),
             "job_id": job.job_id(),
             "status": JobStatus.INITIALIZING.name,
             "date_submit": datetime.datetime.now(datetime.timezone.utc)
