@@ -1,6 +1,9 @@
 import asyncio
+import json
 import time
 
+import numpy
+
 _BASE_SLEEP = 1.0
 _MAX_SLEEP = 30.0
 _SLEEP_GROWTH = 1.2
@@ -54,3 +57,18 @@ async def wait_result_async(
         _raise_if_timeout(start, timeout)
         await asyncio.sleep(sleep)
         sleep = min(sleep * sleep_growth, max_sleep)
+
+
+class QobjEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, numpy.ndarray):
+            return obj.tolist()
+
+        if isinstance(obj, complex):
+            return (obj.real, obj.imag)
+
+        return json.JSONEncoder.default(self, obj)
+
+
+def qasm_qobj_to_dict(qobj):
+    return json.loads(json.dumps(qobj.to_dict(), cls=QobjEncoder))
